@@ -9,7 +9,7 @@ modules = [
     "mateprint",
     ("ui", "mateprint"),
     "gtksourceview",
-    "wnck",
+    "matewnck",
     ("plparser", "totem"),
     "gtop",
     "cajaburn",
@@ -18,11 +18,7 @@ modules = [
     "rsvg",
     "matekeyring",
     "matedesktop",
-    ("ebook", "evolution"),
-    ("ecal", "evolution"),
-    "evince",
-    "braseromedia",
-    "braseroburn",
+    "atril",
     ]
 
 def run_import_tests(builddir, no_import_hooks):
